<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>About</name>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-family:&apos;Sans Serif&apos;; font-size:12pt; font-style:normal;&quot;&gt;&lt;p style=&quot;margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Version: %1&lt;br/&gt;Build date: %2&lt;br/&gt;Build time: %3&lt;br/&gt;Compiler: %4&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-family:&apos;Sans Serif&apos;; font-size:12pt; font-style:normal;&quot;&gt;&lt;p style=&quot;margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Versión: %1&lt;br/&gt;Fecha de compilación: %2&lt;br/&gt;Hora de compilación: %3&lt;br/&gt;Compilador: %4&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-family:&apos;Sans Serif&apos;; font-size:12pt; font-style:normal;&quot;&gt;&lt;p style=&quot;margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Version: %1&lt;br/&gt;Qt version: %5&lt;br/&gt;Drumstick version: %6&lt;br/&gt;Build date: %2&lt;br/&gt;Build time: %3&lt;br/&gt;Compiler: %4&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-family:&apos;Sans Serif&apos;; font-size:12pt; font-style:normal;&quot;&gt;&lt;p style=&quot;margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Versión: %1&lt;br/&gt;Versión de Qt:%5&lt;br/&gt;Versión de Drumstick:%6&lt;br/&gt;Fecha de compilación: %2&lt;br/&gt;Hora de compilación: %3&lt;br/&gt;Compilador: %4&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>AboutClass</name>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Drumstick Metronome&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Metrónomo Drumstick &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://kmetronome.sourceforge.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;http://kmetronome.sourceforge.net&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://kmetronome.sourceforge.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;http://kmetronome.sourceforge.net&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;Copyright © 2002-2021, &lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net?subject=VMPK&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;Pedro Lopez-Cabanillas &amp;lt;plcl@users.sf.net&amp;gt;&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:10pt;&quot;&gt;This program is free software; you can redistribute it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:10pt;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:10pt;&quot;&gt;You should have received a copy of the GNU General Public License
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:10pt;&quot;&gt;along with this program. If not, see &lt;http://www.gnu.org/licenses/&gt;.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;Copyright © 2002-2021, &lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net?subject=VMPK&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;Pedro Lopez-Cabanillas &amp;lt;plcl@users.sf.net&amp;gt;&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:10pt;&quot;&gt;Este programa es software libre; usted puede redistribuirlo bajo las condiciones de la Licencia Pública General GNU publicada por la Free Software Foundation; ya sea la versión 2 de la licencia o (a su elección) cualquier versión posterior.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:10pt;&quot;&gt;Este programa se distribuye SIN NINGUNA GARANTIA, incluso sin la garantía implícita MERCANTIL o de APTITUD PARA UN PROPÓSITO DETERMINADO. Vea la Licencia Pública General GNU para mas detalles.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:10pt;&quot;&gt;Usted debería haber recibido una copia de la Licencia Pública General GNU junto con este programa. En caso contrario escriba a la Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;https://kmetronome.sourceforge.io&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;https://kmetronome.sourceforge.io&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;https://kmetronome.sourceforge.io&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;https://kmetronome.sourceforge.io&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Copyright © 2002-2021, &lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net?subject=VMPK&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;Pedro Lopez-Cabanillas &amp;lt;plcl@users.sf.net&amp;gt;&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;;&quot;&gt;This program is free software; you can redistribute it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;;&quot;&gt;You should have received a copy of the GNU General Public License along with this program; if not, see &lt;/span&gt;&lt;a href=&quot;https://www.gnu.org/licenses/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;https://www.gnu.org/licenses/&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;;&quot;&gt;.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Copyright © 2002-2021, &lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net?subject=VMPK&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;Pedro Lopez-Cabanillas &amp;lt;plcl@users.sf.net&amp;gt;&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;;&quot;&gt;This program is free software; you can redistribute it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;;&quot;&gt;You should have received a copy of the GNU General Public License along with this program; if not, see &lt;/span&gt;&lt;a href=&quot;https://www.gnu.org/licenses/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;https://www.gnu.org/licenses/&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;;&quot;&gt;.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>DrumGrid</name>
    <message>
        <source>Rows:</source>
        <translation>Filas:</translation>
    </message>
    <message>
        <source>Use this button to add new rows (sounds) to the current pattern definition</source>
        <translation>Utilice este botón para añadir nuevas filas (sonidos) a la definición de patrón actual</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <source>Use this button to remove the selected row (sound) from the pattern definition</source>
        <translation>Utilize este botón para eliminar la fila seleccionada (sonido) de la definición de patrón</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Beats:</source>
        <translation>Partes:</translation>
    </message>
    <message>
        <source>Highligh the grid columns while playing</source>
        <translation>Destacar las columnas de la tabla durante la reproducción</translation>
    </message>
    <message>
        <source>Highlight
Columns</source>
        <translation>Destacar
Columnas</translation>
    </message>
    <message>
        <source>This is the current beat number</source>
        <translation>Este es el número de parte actual</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Patrón:</translation>
    </message>
    <message>
        <source>Type a new name and press the &quot;Save&quot; button to create a new pattern, or choose an existing pattern from the drop-down list.</source>
        <translation>Escriba un nuevo nombre y pulse el botón &quot;Guardar&quot; para crear un nuevo patrón, o elija un patrón existente en la lista desplegable.</translation>
    </message>
    <message>
        <source>This button stores the current pattern definition with the name given</source>
        <translation>Este botón almacena la definición del patrón actual con el nombre proporcionado</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>This button deletes the current pattern definition</source>
        <translation>Este botón borra la definición del patrón actual</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Number of beats per measure (bar)</source>
        <translation>Número de partes rítmicas por compás</translation>
    </message>
    <message>
        <source>This is the beat length for the pattern column.</source>
        <translation>Esta es la duración de cada columna del patrón.</translation>
    </message>
    <message>
        <source>Whole</source>
        <translation type="vanished">Redonda </translation>
    </message>
    <message>
        <source>Half</source>
        <translation type="vanished">Blanca</translation>
    </message>
    <message>
        <source>Quarter</source>
        <translation type="vanished">Negra</translation>
    </message>
    <message>
        <source>Eighth</source>
        <translation type="vanished">Corchea</translation>
    </message>
    <message>
        <source>Sixteenth</source>
        <translation type="vanished">Semicorchea</translation>
    </message>
    <message>
        <source>Thirty-Second</source>
        <translation type="vanished">Fusa</translation>
    </message>
    <message>
        <source>Sixty-Fourth</source>
        <translation type="vanished">Semifusa</translation>
    </message>
    <message>
        <source>This button starts playing the current pattern</source>
        <translation>Este botón inicia la reproducción del patrón rítmico</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>This button stops the playback</source>
        <translation>Este botón termina la reproducción</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>QPM: quarters per minute</source>
        <translation>NPM: negras por minuto</translation>
    </message>
    <message>
        <source>QPM:</source>
        <comment>Quarters per Minute</comment>
        <translation>NPM:</translation>
    </message>
    <message>
        <source>This is the current tempo in quarters per minute</source>
        <translation>Este es el tempo actual (en negras por minuto)</translation>
    </message>
    <message>
        <source>Drag the slider handle to change the tempo, in quarters per minute</source>
        <translation>Arrastre el deslizador para cambiar el tempo, en negras por minuto</translation>
    </message>
    <message>
        <source>This is the pattern table, beats as columns and sounds as rows</source>
        <translation>Esta es la tabla de patrones, partes como columnas y sonidos como filas</translation>
    </message>
    <message>
        <source>Pattern Editor</source>
        <translation>Editor de patrones</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <source>Remove Pattern</source>
        <translation>Eliminar patrón</translation>
    </message>
    <message>
        <source>Do you want to remove the current pattern?</source>
        <translation>¿Desea eliminar el patrón actual?</translation>
    </message>
    <message>
        <source>Sample Pattern</source>
        <comment>name of an automatically created pattern</comment>
        <translation>Patrón de ejemplo</translation>
    </message>
    <message>
        <source>Insert Pattern Row</source>
        <translation>Insertar fila en el patrón</translation>
    </message>
    <message>
        <source>Drum Key:</source>
        <translation>Sonido de percusión:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation></translation>
    </message>
    <message>
        <source>Please select one, and only one row</source>
        <translation>Por favor seleccione una fila, y sólamente una</translation>
    </message>
    <message>
        <source>Remove Row</source>
        <translation>Eliminar fila</translation>
    </message>
    <message>
        <source>Do you want to remove the selected pattern row?</source>
        <translation>¿Desea eliminar la fila seleccionada del patrón?</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>&amp;Home</source>
        <translation>&amp;Inicio</translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Atrás</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Ampliar</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Reducir</translation>
    </message>
</context>
<context>
    <name>KMetroPreferences</name>
    <message>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
</context>
<context>
    <name>KMetroPreferencesBase</name>
    <message>
        <source>If this checkbox is activated, the the program will remember the connections for the input and output ports, and try to reconnect them at program startup.</source>
        <translation>Si esta casilla está marcada, el programa recordará las conexiones para los puertos de entrada y de salida, e intentará su reconexión al inicio del programa.</translation>
    </message>
    <message>
        <source>Automatic ports connection on startup</source>
        <translation>Conexión automática de los puertos al iniciar</translation>
    </message>
    <message>
        <source>Optional input port conn:</source>
        <translation>Conexión de la entrada:</translation>
    </message>
    <message>
        <source>This is the optional connection for the MIDI IN port.</source>
        <translation>Esta es la conexión opcional del puerto MIDI IN.</translation>
    </message>
    <message>
        <source>Output port connection:</source>
        <translation>Conexión de la salida:</translation>
    </message>
    <message>
        <source>This is the mandatory connection for the MIDI OUT port</source>
        <translation>Esta es la conexión obligatoria del puerto MIDI OUT</translation>
    </message>
    <message>
        <source>Output instrument:</source>
        <translation>Instrumento receptor:</translation>
    </message>
    <message>
        <source>This is the definition of the instrument connected to the MIDI OUT port</source>
        <translation>Esta es la definición del instrumento conectado al puerto MIDI OUT</translation>
    </message>
    <message>
        <source>Bank:</source>
        <translation>Banco:</translation>
    </message>
    <message>
        <source>This is the Bank of the selected MIDI program</source>
        <translation>Este es el banco del programa MIDI seleccionado</translation>
    </message>
    <message>
        <source>Channel:</source>
        <translation>Canal:</translation>
    </message>
    <message>
        <source>This is the MIDI channel, between 1 and 16. 
General MIDI uses the channel 10 for percussion sounds.</source>
        <translation>Este es el canal MIDI, entre 1 y 16.
General MIDI utiliza el canal 10 para sonidos de percusión.</translation>
    </message>
    <message>
        <source>Program:</source>
        <translation>Programa:</translation>
    </message>
    <message>
        <source>This is the MIDI program</source>
        <translation>Este es el programa MIDI</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Resolución:</translation>
    </message>
    <message>
        <source>This is the MIDI time resolution (number of ticks in a quarter note)</source>
        <translation>Esta es la resolución de tiempo MIDI (número de tics por negra)</translation>
    </message>
    <message>
        <source>Weak note:</source>
        <translation>Nota débil:</translation>
    </message>
    <message>
        <source>This is the sound of the weak notes for the automatic patterns</source>
        <translation>Este es sonido de las notas débiles en el patrón rítmico automático</translation>
    </message>
    <message>
        <source>Note duration:</source>
        <translation>Duración:</translation>
    </message>
    <message>
        <source>This is the note duration in ticks, when using NOTE OFF events</source>
        <translation>Esta es la duración de las notas en tics, cuando se utilizan eventos NOTE OFF</translation>
    </message>
    <message>
        <source>Strong note:</source>
        <translation>Nota fuerte:</translation>
    </message>
    <message>
        <source>This is the sound of the strong notes for the automatic patterns</source>
        <translation>Este es el sonido de las notas fuertes en el patrón rítmico automático</translation>
    </message>
    <message>
        <source>Optional setting to send NOTE OFF events</source>
        <translation>Opción para emitir eventos NOTE OFF</translation>
    </message>
    <message>
        <source>Send NOTE OFF events</source>
        <translation>Emitir eventos NOTE OFF</translation>
    </message>
    <message>
        <source>Forced Dark Mode</source>
        <translation>Modo oscuro forzado</translation>
    </message>
    <message>
        <source>Internal Icon Theme</source>
        <translation>Tema de iconos interno</translation>
    </message>
    <message>
        <source>Qt Style:</source>
        <translation>Estilo de Qt:</translation>
    </message>
</context>
<context>
    <name>KMetronome</name>
    <message>
        <source>Fatal error from the ALSA sequencer. This usually happens when the kernel doesn&apos;t have ALSA support, or the device node (/dev/snd/seq) doesn&apos;t exists, or the kernel module (snd_seq) is not loaded. Please check your ALSA/MIDI configuration. Returned error was: %1</source>
        <translation>Error fatal del secuenciador ALSA. Esto ocurre normalmente cuando el núcleo no tiene soporte ALSA, o el nodo de dispositivo (/dev/snd/seq) no existe, o bien el módulo del núcleo (snd_seq) no ha sido cargado. Por favor, compruebe la configuración de ALSA y MIDI.El error devuelto ha sido: %1</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Import Patterns</source>
        <translation>Importar patrones</translation>
    </message>
    <message>
        <source>Pattern Files (*.pat)</source>
        <translation>Archivos de patrones (*.pat)</translation>
    </message>
    <message>
        <source>Export Patterns</source>
        <translation>Exportar patrones</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Enter new Tempo:</source>
        <translation>Introducir nuevo tempo:</translation>
    </message>
    <message>
        <source>Automatic</source>
        <comment>the pattern is created automatically</comment>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Language Changed</source>
        <translation>Idioma cambiado</translation>
    </message>
    <message>
        <source>The language for this application is going to change to %1. Do you want to continue?</source>
        <translation>El idioma para esta aplicación va a cambiar a %1. ¿Quiere continuar?</translation>
    </message>
</context>
<context>
    <name>KMetronomeWindow</name>
    <message>
        <source>Drumstick Metronome</source>
        <translation>Metrónomo Drumstick</translation>
    </message>
    <message>
        <source>This button starts playing the rhythm pattern</source>
        <translation>Este botón inicia la reproducción del patrón rítmico</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>This button stops playing the rhythm pattern</source>
        <translation>Este botón detiene la reproducción del patrón rítmico</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>This button opens the configuration window</source>
        <translation>Este botón abre la ventana de configuración</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <source>This button opens the pattern editor</source>
        <translation>Este botón abre el editor de patrones</translation>
    </message>
    <message>
        <source>Patterns</source>
        <translation>Patrones</translation>
    </message>
    <message>
        <source>This button exits the program</source>
        <translation>Este botón termina el programa</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Number of measures (bars) and beats played from beginning</source>
        <translation>Número de compases y partes ejecutadas desde el principio</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Patrón:</translation>
    </message>
    <message>
        <source>This is the pattern definition to play, either &quot;Automatic&quot; or a custom defined one.</source>
        <translation>Esta es la definición de patrón que se reproducirá, bien &quot;Automático&quot; o bién una definición personalizada.</translation>
    </message>
    <message>
        <source>Beats/Bar:</source>
        <translation>Partes/Compás:</translation>
    </message>
    <message>
        <source>This is the number of beats for each measure (bar).
Values are from 1 to 32.
It is the numerator of the time signature specification.</source>
        <translation>Este es el número de partes de cada compás.
Valores admisibles entre 1 y 32.
Este es el numerador de la especificación de ritmo.</translation>
    </message>
    <message>
        <source>Beat Length:</source>
        <translation>Figura rítmica:</translation>
    </message>
    <message>
        <source>This is the beat length.
Values mean 1, 2, 4, 8, 16, 32 and 64.
It is the denominator in the time signature specification.</source>
        <translation>Esta es la duración de una parte rítmica.
Los valores significan 1, 2, 4, 8, 16, 32 y 64.
Es el denominador de la especificación de ritmo.</translation>
    </message>
    <message>
        <source>Whole</source>
        <translation type="vanished">Redonda </translation>
    </message>
    <message>
        <source>Half</source>
        <translation type="vanished">Blanca</translation>
    </message>
    <message>
        <source>Quarter</source>
        <translation type="vanished">Negra</translation>
    </message>
    <message>
        <source>Eighth</source>
        <translation type="vanished">Corchea</translation>
    </message>
    <message>
        <source>Sixteenth</source>
        <translation type="vanished">Semicorchea</translation>
    </message>
    <message>
        <source>Thirty-Second</source>
        <translation type="vanished">Fusa</translation>
    </message>
    <message>
        <source>Sixty-Fourth</source>
        <translation type="vanished">Semifusa</translation>
    </message>
    <message>
        <source>Weak</source>
        <comment>weak notes MIDI velocity</comment>
        <translation>Débil</translation>
    </message>
    <message>
        <source>Strong</source>
        <comment>strong notes MIDI velocity</comment>
        <translation>Fuerte</translation>
    </message>
    <message>
        <source>Volume</source>
        <comment>audio volume level</comment>
        <translation>Volumen</translation>
    </message>
    <message>
        <source>Pan</source>
        <comment>audio panning</comment>
        <translation>Balance</translation>
    </message>
    <message>
        <source>This is the velocity of the weak notes in the automatic rhythm pattern (all of them, except the first one)</source>
        <translation>Esta es la velocidad de las notas débiles en el patrón rítmico automático (todas ellas excepto la primera)</translation>
    </message>
    <message>
        <source>This is the velocity of the strong note in the automatic rhythm pattern (the first one)</source>
        <translation>Esta es la velocidad de las notas fuertes en el patrón rítmico automático (la primera)</translation>
    </message>
    <message>
        <source>This is the MIDI volume control (CC7)</source>
        <translation>Este es el control de volumen (CC7)</translation>
    </message>
    <message>
        <source>This is the MIDI pan control (CC10)</source>
        <translation>Este es el control de balance (CC10)</translation>
    </message>
    <message>
        <source>This is the musical name of the tempo value</source>
        <translation>Esta es la denominación musical del valor del tempo</translation>
    </message>
    <message>
        <source>The current &lt;i&gt;tempo&lt;/i&gt; value</source>
        <translation>El valor actual del &lt;i&gt;tempo&lt;/i&gt;</translation>
    </message>
    <message>
        <source>Tempo (in quarters per minute)</source>
        <translation>Tempo (en negras por minuto)</translation>
    </message>
    <message>
        <source>This slider changes the &lt;i&gt;tempo&lt;/i&gt;, or speed of the rhythm.
Values are 25 to 250 quarters per minute (&lt;i&gt;Maelzel Metronome units&lt;/i&gt;).</source>
        <translation>Este deslizador cambia el &lt;i&gt;tempo&lt;/i&gt;, o velocidad del ritmo.
Los valores van desde 25 hasta 250 negras por minuto. (&lt;i&gt;unidades del Metrónomo de Mälzel&lt;/i&gt;).</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edición</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>language</source>
        <translation>idioma</translation>
    </message>
    <message>
        <source>toolBar</source>
        <translation>barra de herramientas</translation>
    </message>
    <message>
        <source>Import Patterns</source>
        <translation>Importar patrones</translation>
    </message>
    <message>
        <source>Export Patterns</source>
        <translation>Exportar patrones</translation>
    </message>
    <message>
        <source>Play/Stop</source>
        <translation>Comenzar/Parar</translation>
    </message>
    <message>
        <source>Edit Patterns</source>
        <translation>Editar patrones</translation>
    </message>
    <message>
        <source>Configuration</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <source>about</source>
        <translation>acerca de</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Show Action Buttons</source>
        <translation>Mostrar botones de acción</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation>Mostrar barra de herramientas</translation>
    </message>
    <message>
        <source>about Qt</source>
        <translation>acerca de Qt</translation>
    </message>
    <message>
        <source>Help Contents</source>
        <translation>Contenidos de ayuda</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Whole</source>
        <translation>Redonda</translation>
    </message>
    <message>
        <source>Half</source>
        <translation>Blanca</translation>
    </message>
    <message>
        <source>Quarter</source>
        <translation>Negra</translation>
    </message>
    <message>
        <source>Eight</source>
        <translation>Corchea</translation>
    </message>
    <message>
        <source>Sixteenth</source>
        <translation>Semicorchea</translation>
    </message>
    <message>
        <source>Thirty-Second</source>
        <translation>Fusa</translation>
    </message>
    <message>
        <source>Sixty-Fourth</source>
        <translation>Semifusa</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Cakewalk Instrument Definition File</source>
        <translation>Archivo de definición de instrumentos de Cakewalk</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
</context>
<context>
    <name>SequencerAdapter</name>
    <message>
        <source>No connection</source>
        <translation>Sin conexión</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:101</name>
    <message>
        <source>Drag the slider handle to change the tempo, in quarters per minute</source>
        <translation type="vanished">Arrastre el deslizador para cambiar el tempo, en negras por minuto</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:104</name>
    <message>
        <source>MIDI Metronome</source>
        <translation type="vanished">Metrónomo MIDI</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:107</name>
    <message>
        <source>This button starts playing the rhythm pattern</source>
        <translation type="vanished">Este botón inicia la reproducción del patrón rítmico</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:110</name>
    <message>
        <source>Play</source>
        <translation type="vanished">Reproducir</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:113</name>
    <message>
        <source>This button stops playing the rhythm pattern</source>
        <translation type="vanished">Este botón detiene la reproducción del patrón rítmico</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:116</name>
    <message>
        <source>Stop</source>
        <translation type="vanished">Parar</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:119</name>
    <message>
        <source>This button opens the configuration window</source>
        <translation type="vanished">Este botón abre la ventana de configuración</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:12</name>
    <message>
        <source>Save</source>
        <translation type="vanished">Guardar</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:122</name>
    <message>
        <source>Settings</source>
        <translation type="vanished">Preferencias</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:125</name>
    <message>
        <source>This button opens the pattern editor</source>
        <translation type="vanished">Este botón abre el editor de patrones</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:128</name>
    <message>
        <source>Patterns</source>
        <translation type="vanished">Patrones</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:131</name>
    <message>
        <source>This button exits the program</source>
        <translation type="vanished">Este botón termina el programa</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:134</name>
    <message>
        <source>Quit</source>
        <translation type="vanished">Salir</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:137</name>
    <message>
        <source>Number of measures (bars) and beats played from beginning</source>
        <translation type="vanished">Número de compases y partes ejecutadas desde el principio</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:140</name>
    <message>
        <source>Pattern:</source>
        <translation type="vanished">Patrón:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:143</name>
    <message>
        <source>This is the pattern definition to play, either &quot;Automatic&quot; or a custom defined one.</source>
        <translation type="vanished">Esta es la definición de patrón que se reproducirá, bien &quot;Automático&quot; o bién una definición personalizada.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:146</name>
    <message>
        <source>Beats/Bar:</source>
        <translation type="vanished">Partes/Compás:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:149</name>
    <message>
        <source>This is the number of beats for each measure (bar).
Values are from 1 to 32.
It is the numerator of the time signature specification.</source>
        <translation type="vanished">Este es el número de partes de cada compás.
Valores admisibles entre 1 y 32.
Este es el numerador de la especificación de ritmo.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:15</name>
    <message>
        <source>This button deletes the current pattern definition</source>
        <translation type="vanished">Este botón borra la definición del patrón actual</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:154</name>
    <message>
        <source>Beat Length:</source>
        <translation type="vanished">Figura rítmica:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:157</name>
    <message>
        <source>This is the beat length.
Values mean 1, 2, 4, 8, 16, 32 and 64.
It is the denominator in the time signature specification.</source>
        <translation type="vanished">Esta es la duración de una parte rítmica.
Los valores significan 1, 2, 4, 8, 16, 32 y 64.
Es el denominador de la especificación de ritmo.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:162</name>
    <message>
        <source>Whole</source>
        <translation type="vanished">Redonda </translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:165</name>
    <message>
        <source>Half</source>
        <translation type="vanished">Blanca</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:168</name>
    <message>
        <source>Quarter</source>
        <translation type="vanished">Negra</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:171</name>
    <message>
        <source>Eighth</source>
        <translation type="vanished">Corchea</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:174</name>
    <message>
        <source>Sixteenth</source>
        <translation type="vanished">Semicorchea</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:177</name>
    <message>
        <source>Thirty-Second</source>
        <translation type="vanished">Fusa</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:18</name>
    <message>
        <source>Delete</source>
        <translation type="vanished">Eliminar</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:180</name>
    <message>
        <source>Sixty-Fourth</source>
        <translation type="vanished">Semifusa</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:183</name>
    <message>
        <source>Weak</source>
        <translation type="vanished">Débil</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:186</name>
    <message>
        <source>Strong</source>
        <translation type="vanished">Fuerte</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:189</name>
    <message>
        <source>Volume</source>
        <translation type="vanished">Volumen</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:192</name>
    <message>
        <source>Pan</source>
        <translation type="vanished">Balance</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:195</name>
    <message>
        <source>This is the velocity of the weak notes in the automatic rhythm pattern (all of them, except the first one)</source>
        <translation type="vanished">Esta es la velocidad de las notas débiles en el patrón rítmico automático (todas ellas excepto la primera)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:198</name>
    <message>
        <source>This is the velocity of the strong note in the automatic rhythm pattern (the first one)</source>
        <translation type="vanished">Esta es la velocidad de las notas fuertes en el patrón rítmico automático (la primera)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:201</name>
    <message>
        <source>This is the MIDI volume control (CC7)</source>
        <translation type="vanished">Este es el control de volumen (CC7)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:204</name>
    <message>
        <source>This is the MIDI pan control (CC10)</source>
        <translation type="vanished">Este es el control de balance (CC10)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:207</name>
    <message>
        <source>This is the musical name of the tempo value</source>
        <translation type="vanished">Esta es la denominación musical del valor del tempo</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:21</name>
    <message>
        <source>Rows:</source>
        <translation type="vanished">Filas:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:210</name>
    <message>
        <source>The current &lt;i&gt;tempo&lt;/i&gt; value</source>
        <translation type="vanished">El valor actual del &lt;i&gt;tempo&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:213</name>
    <message>
        <source>Tempo (in quarters per minute)</source>
        <translation type="vanished">Tempo (en negras por minuto)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:216</name>
    <message>
        <source>This slider changes the &lt;i&gt;tempo&lt;/i&gt;, or speed of the rhythm.
Values are 25 to 250 quarters per minute (&lt;i&gt;Maelzel Metronome units&lt;/i&gt;).</source>
        <translation type="vanished">Este deslizador cambia el &lt;i&gt;tempo&lt;/i&gt;, o velocidad del ritmo.
Los valores van desde 25 hasta 250 negras por minuto. (&lt;i&gt;unidades del Metrónomo de Mälzel&lt;/i&gt;).</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:220</name>
    <message>
        <source>If this checkbox is activated, the the program will remember the connections for the input and output ports, and try to reconnect them at program startup.</source>
        <translation type="vanished">Si esta casilla está marcada, el programa recordará las conexiones para los puertos de entrada y de salida, e intentará su reconexión al inicio del programa.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:223</name>
    <message>
        <source>Automatic ports connection on startup</source>
        <translation type="vanished">Conexión automática de los puertos al iniciar</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:226</name>
    <message>
        <source>Optional input port conn:</source>
        <translation type="vanished">Conexión de la entrada:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:229</name>
    <message>
        <source>This is the optional connection for the MIDI IN port.</source>
        <translation type="vanished">Esta es la conexión opcional del puerto MIDI IN.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:232</name>
    <message>
        <source>Output port connection:</source>
        <translation type="vanished">Conexión de la salida:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:235</name>
    <message>
        <source>This is the mandatory connection for the MIDI OUT port</source>
        <translation type="vanished">Esta es la conexión obligatoria del puerto MIDI OUT</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:238</name>
    <message>
        <source>Output instrument:</source>
        <translation type="vanished">Instrumento receptor:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:24</name>
    <message>
        <source>Use this button to add new rows (sounds) to the current pattern definition</source>
        <translation type="vanished">Utilice este botón para añadir nuevas filas (sonidos) a la definición de patrón actual</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:241</name>
    <message>
        <source>This is the definition of the instrument connected to the MIDI OUT port</source>
        <translation type="vanished">Esta es la definición del instrumento conectado al puerto MIDI OUT</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:244</name>
    <message>
        <source>Bank:</source>
        <translation type="vanished">Banco:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:247</name>
    <message>
        <source>This is the Bank of the selected MIDI program</source>
        <translation type="vanished">Este es el banco del programa MIDI seleccionado</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:250</name>
    <message>
        <source>Channel:</source>
        <translation type="vanished">Canal:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:253</name>
    <message>
        <source>This is the MIDI channel, between 1 and 16. 
General MIDI uses the channel 10 for percussion sounds.</source>
        <translation type="vanished">Este es el canal MIDI, entre 1 y 16.
General MIDI utiliza el canal 10 para sonidos de percusión.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:257</name>
    <message>
        <source>Program:</source>
        <translation type="vanished">Programa:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:260</name>
    <message>
        <source>This is the MIDI program</source>
        <translation type="vanished">Este es el programa MIDI</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:263</name>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Resolución:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:266</name>
    <message>
        <source>This is the MIDI time resolution (number of ticks in a quarter note)</source>
        <translation type="vanished">Esta es la resolución de tiempo MIDI (número de tics por negra)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:269</name>
    <message>
        <source>Weak note:</source>
        <translation type="vanished">Nota débil:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:27</name>
    <message>
        <source>Add</source>
        <translation type="vanished">Añadir</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:272</name>
    <message>
        <source>This is the sound of the weak notes for the automatic patterns</source>
        <translation type="vanished">Este es sonido de las notas débiles en el patrón rítmico automático</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:275</name>
    <message>
        <source>Note duration:</source>
        <translation type="vanished">Duración:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:278</name>
    <message>
        <source>This is the note duration in ticks, when using NOTE OFF events</source>
        <translation type="vanished">Esta es la duración de las notas en tics, cuando se utilizan eventos NOTE OFF</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:281</name>
    <message>
        <source>Strong note:</source>
        <translation type="vanished">Nota fuerte:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:284</name>
    <message>
        <source>This is the sound of the strong notes for the automatic patterns</source>
        <translation type="vanished">Este es el sonido de las notas fuertes en el patrón rítmico automático</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:287</name>
    <message>
        <source>Optional setting to send NOTE OFF events</source>
        <translation type="vanished">Opción para emitir eventos NOTE OFF</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:290</name>
    <message>
        <source>Send NOTE OFF events</source>
        <translation type="vanished">Emitir eventos NOTE OFF</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:293</name>
    <message>
        <source>If this option is activated, the knobs are drawn using a custom style</source>
        <translation type="vanished">Si esta opción está seleccionada, los botones rotatorios se dibujarán con un estilo personalizado</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:296</name>
    <message>
        <source>Styled Knobs</source>
        <translation type="vanished">Botones decorados</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:297</name>
    <message>
        <source>Your names</source>
        <translation type="vanished">Pedro López-Cabanillas</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:298</name>
    <message>
        <source>Your emails</source>
        <translation type="vanished">plcl@users.sf.net</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:3</name>
    <message>
        <source>Pattern:</source>
        <translation type="vanished">Patrón:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:30</name>
    <message>
        <source>Use this button to remove the selected row (sound) from the pattern definition</source>
        <translation type="vanished">Utilize este botón para eliminar la fila seleccionada (sonido) de la definición de patrón</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:33</name>
    <message>
        <source>Remove</source>
        <translation type="vanished">Eliminar</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:36</name>
    <message>
        <source>Beats:</source>
        <translation type="vanished">Partes:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:39</name>
    <message>
        <source>Highligh the grid columns while playing</source>
        <translation type="vanished">Destacar las columnas de la tabla durante la reproducción</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:42</name>
    <message>
        <source>Highlight
Columns</source>
        <translation type="vanished">Destacar
Columnas</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:46</name>
    <message>
        <source>This is the current beat number</source>
        <translation type="vanished">Este es el número de parte actual</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:49</name>
    <message>
        <source>This is the pattern table, beats as columns and sounds as rows</source>
        <translation type="vanished">Esta es la tabla de patrones, partes como columnas y sonidos como filas</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:52</name>
    <message>
        <source>Number of beats per measure (bar)</source>
        <translation type="vanished">Número de partes rítmicas por compás</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:55</name>
    <message>
        <source>This is the beat length for the pattern column.</source>
        <translation type="vanished">Esta es la duración de cada columna del patrón</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:58</name>
    <message>
        <source>Whole</source>
        <translation type="vanished">Redonda </translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:6</name>
    <message>
        <source>Type a new name and press the &quot;Save&quot; button to create a new pattern, or choose an existing pattern from the drop-down list.</source>
        <translation type="vanished">Escriba un nuevo nombre y pulse el botón &quot;Guardar&quot; para crear un nuevo patrón, o elija un patrón existente en la lista desplegable.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:61</name>
    <message>
        <source>Half</source>
        <translation type="vanished">Blanca</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:64</name>
    <message>
        <source>Quarter</source>
        <translation type="vanished">Negra</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:67</name>
    <message>
        <source>Eighth</source>
        <translation type="vanished">Corchea</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:70</name>
    <message>
        <source>Sixteenth</source>
        <translation type="vanished">Semicorchea</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:73</name>
    <message>
        <source>Thirty-Second</source>
        <translation type="vanished">Fusa</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:76</name>
    <message>
        <source>Sixty-Fourth</source>
        <translation type="vanished">Semifusa</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:79</name>
    <message>
        <source>This button starts playing the current pattern</source>
        <translation type="vanished">Este botón inicia la reproducción del patrón rítmico</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:82</name>
    <message>
        <source>Play</source>
        <translation type="vanished">Reproducir</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:85</name>
    <message>
        <source>This button stops the playback</source>
        <translation type="vanished">Este botón termina la reproducción</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:88</name>
    <message>
        <source>Stop</source>
        <translation type="vanished">Parar</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:9</name>
    <message>
        <source>This button stores the current pattern definition with the name given</source>
        <translation type="vanished">Este botón almacena la definición del patrón actual con el nombre proporcionado</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:91</name>
    <message>
        <source>QPM: quarters per minute</source>
        <translation type="vanished">NPM: negras por minuto</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:94</name>
    <message>
        <source>QPM:</source>
        <translation type="vanished">NPM:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:97</name>
    <message>
        <source>This is the current tempo in quarters per minute</source>
        <translation type="vanished">Este es el tempo actual (en negras por minuto)</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:278</name>
    <message>
        <source>Do you want to remove the current pattern?</source>
        <translation type="vanished">¿Desea eliminar el patrón actual?</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:279</name>
    <message>
        <source>Remove Pattern</source>
        <translation type="vanished">Eliminar patrón</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:333</name>
    <message>
        <source>Sample Pattern</source>
        <translation type="vanished">Patrón de ejemplo</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:364</name>
    <message>
        <source>Insert Pattern Row</source>
        <translation type="vanished">Insertar fila en el patrón</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:365</name>
    <message>
        <source>Drum Key:</source>
        <translation type="vanished">Sonido de percusión:</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:386</name>
    <message>
        <source>Please select one, and only one row</source>
        <translation type="vanished">Por favor seleccione una fila, y sólamente una</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:388</name>
    <message>
        <source>Do you want to remove the selected pattern row?</source>
        <translation type="vanished">¿Desea eliminar la fila seleccionada del patrón?</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:389</name>
    <message>
        <source>Remove Row</source>
        <translation type="vanished">Eliminar fila</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:51</name>
    <message>
        <source>Pattern Editor</source>
        <translation type="vanished">Editor de patrones</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:67</name>
    <message>
        <source>Cut</source>
        <translation type="vanished">Cortar</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:68</name>
    <message>
        <source>Copy</source>
        <translation type="vanished">Copiar</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:69</name>
    <message>
        <source>Paste</source>
        <translation type="vanished">Pegar</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:114</name>
    <message>
        <source>Play/Stop</source>
        <translation type="vanished">Comenzar/Parar</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:118</name>
    <message>
        <source>Show Action Buttons</source>
        <translation type="vanished">Mostrar botones de acción</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:125</name>
    <message>
        <source>Patterns</source>
        <translation type="vanished">Patrones</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:130</name>
    <message>
        <source>Import Patterns</source>
        <translation type="vanished">Importar patrones</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:135</name>
    <message>
        <source>Export Patterns</source>
        <translation type="vanished">Exportar patrones</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:497</name>
    <message>
        <source>*.pat|Pattern Files (*.pat)</source>
        <translation type="vanished">*.pat|Archivos de patrones (*.pat)</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:498</name>
    <message>
        <source>Import Patterns</source>
        <translation type="vanished">Importar patrones</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:510</name>
    <message>
        <source>*.pat|Pattern Files (*.pat)</source>
        <translation type="vanished">*.pat|Archivos de patrones (*.pat)</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:511</name>
    <message>
        <source>Export Patterns</source>
        <translation type="vanished">Exportar patrones</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:527</name>
    <message>
        <source>Patterns</source>
        <translation type="vanished">Patrones</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:87</name>
    <message>
        <source>Fatal error from the ALSA sequencer. This usually happens when the kernel doesn&apos;t have ALSA support, or the device node (/dev/snd/seq) doesn&apos;t exists, or the kernel module (snd_seq) is not loaded. Please check your ALSA/MIDI configuration. Returned error was: %1</source>
        <translation type="vanished">Error fatal del secuenciador ALSA. Esto ocurre normalmente cuando el núcleo no tiene soporte ALSA, o el nodo de dispositivo (/dev/snd/seq) no existe, o bien el módulo del núcleo (snd_seq) no ha sido cargado. Por favor, compruebe la configuración de ALSA y MIDI.El error devuelto ha sido: %1</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:93</name>
    <message>
        <source>Error</source>
        <translation type="vanished">Error</translation>
    </message>
</context>
<context>
    <name>src/kmetronomeview.cpp:145</name>
    <message>
        <source>Tempo</source>
        <translation type="vanished">Tempo</translation>
    </message>
    <message>
        <source>Enter new Tempo:</source>
        <translation type="vanished">Introducir nuevo tempo:</translation>
    </message>
</context>
<context>
    <name>src/kmetronomeview.cpp:179</name>
    <message>
        <source>Automatic</source>
        <translation type="vanished">Automático</translation>
    </message>
</context>
<context>
    <name>src/kmetropreferences.cpp:29</name>
    <message>
        <source>Preferences</source>
        <translation type="vanished">Preferencias</translation>
    </message>
</context>
<context>
    <name>src/main.cpp:29</name>
    <message>
        <source>KDE MIDI metronome using ALSA sequencer</source>
        <translation type="vanished">Metrónomo MIDI de KDE utilizando el secuenciador de ALSA </translation>
    </message>
</context>
<context>
    <name>src/main.cpp:41</name>
    <message>
        <source>KMetronome</source>
        <translation type="vanished">KMetronome</translation>
    </message>
</context>
<context>
    <name>src/main.cpp:43</name>
    <message>
        <source>(C) 2005-2012 Pedro Lopez-Cabanillas</source>
        <translation type="vanished">(C) 2005-2012 Pedro Lopez-Cabanillas</translation>
    </message>
</context>
<context>
    <name>src/main.cpp:45</name>
    <message>
        <source>Pedro Lopez-Cabanillas</source>
        <translation type="vanished">Pedro Lopez-Cabanillas</translation>
    </message>
</context>
<context>
    <name>src/sequenceradapter.cpp:65</name>
    <message>
        <source>No connection</source>
        <translation type="vanished">Sin conexión</translation>
    </message>
</context>
</TS>
